/*
 * JScript for creating draggable elements without JQuery.
 * Adapted for BARIX from the original source from Rob Crowther
 * posted on JSFiddle:
 * http://jsfiddle.net/robertc/kKuqH/
 * 
 * Date        Who  What was modified
 * ---------------------------------------------------------------------------------------
 * 05.10.2016  ASI  + Added initDragElem() function and renamed functions to fit our 
 *                    usual naming convention (i.e. thisIsFunctionName)
 * ---------------------------------------------------------------------------------------
 *
 * How it works:
 * 1. Include draggable.js in the <script> section of your HTML page
 *
 * 2. Create a div element encapsulating the content you wanna drag, and add an ID to it
 * for example:
 * <div id="drag_me"></div>
 *
 * 3. Style it as you like with CSS, and include the css file in your page, for example:
 *
 *  #drag_me {
 *     visibility: hidden;
 *     position: absolute;
 *     left: 0px;
 *     top: 0px;
 *     width:100%;
 *     height:100%;
 *     text-align:center;
 *     z-index: 1000;
 *     -webkit-user-drag: element;
 * }
 *
 * #drag_me div {
 *     width:390px;
 *     height:410px;
 *     margin: 100px auto;
 *     background-color: #fff;
 *     border:1px solid #000;
 *     padding:15px;
 *    text-align:center;
 * }
 *
 * 4. On page load, call the init function from this script passing the ID of the element you want
 *    to drag in order to add the drag event handlers
 *    for example:
 *    <body onload="initFunction1();initFunction2();initDragElem('drag_me');">
 * 
 * 5. For the moment you can have only one draggable element per page
 *
 */
var dragElem;

function initDragElem(elemId){
    dragElem=document.getElementById(elemId); 
	dragElem.addEventListener('dragstart',dragStart,false); 
	document.body.addEventListener('dragover',dragOver,false); 
	document.body.addEventListener('drop',dragDrop,false); 
}

function dragStart(event) {
    var style = window.getComputedStyle(event.target, null);
    event.dataTransfer.setData("text/plain",
    (parseInt(style.getPropertyValue("left"),10) - event.clientX) + ',' + (parseInt(style.getPropertyValue("top"),10) - event.clientY));
} 

function dragOver(event) { 
    event.preventDefault(); 
    return false; 
} 

function dragDrop(event) { 
    var offset = event.dataTransfer.getData("text/plain").split(',');
    dragElem.style.left = (event.clientX + parseInt(offset[0],10)) + 'px';
    dragElem.style.top = (event.clientY + parseInt(offset[1],10)) + 'px';
    event.preventDefault();
    return false;
} 

